package com.ruoyi.frequency.platformanswertype.service;

import java.util.List;
import com.ruoyi.frequency.platformanswertype.entity.PlatformAnswerType;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 平台有问必答类型Service接口
 * 
 * @author liwenlong
 * @date 2024-02-21
 */
public interface PlatformAnswerTypeService extends IService<PlatformAnswerType>
{
    /**
     * 查询平台有问必答类型
     * 
     * @param id 平台有问必答类型主键
     * @return 平台有问必答类型
     */
    public PlatformAnswerType selectPlatformAnswerTypeById(Long id);

    /**
     * 查询平台有问必答类型列表
     * 
     * @param platformAnswerType 平台有问必答类型
     * @return 平台有问必答类型集合
     */
    public List<PlatformAnswerType> selectPlatformAnswerTypeList(PlatformAnswerType platformAnswerType);

    /**
     * 新增平台有问必答类型
     * 
     * @param platformAnswerType 平台有问必答类型
     * @return 结果
     */
    public int insertPlatformAnswerType(PlatformAnswerType platformAnswerType);

    /**
     * 修改平台有问必答类型
     * 
     * @param platformAnswerType 平台有问必答类型
     * @return 结果
     */
    public int updatePlatformAnswerType(PlatformAnswerType platformAnswerType);

    /**
     * 批量删除平台有问必答类型
     * 
     * @param ids 需要删除的平台有问必答类型主键集合
     * @return 结果
     */
    public int deletePlatformAnswerTypeByIds(Long[] ids,Integer delFlag);

}
